Tutorial
========

.. grid::

    .. grid-item-card::

        .. toctree::
            :maxdepth: 1

            intro.rst

        .. raw:: html

            <img style="max-width: 240px;" src="/_images/intro-6.png"/>


    .. grid-item-card::

        .. toctree::
            :maxdepth: 1

            heatmap_variants.rst

        .. raw:: html

            <img style="max-width: 240px;" src="/_images/heatmap_variants-2.png"/>

.. grid::

    .. grid-item-card::

        .. toctree::
            :maxdepth: 1

            upset.rst

        .. raw:: html

            <img style="max-width: 240px;" src="/_images/upset-3.png"/>

    .. grid-item-card::

        .. toctree::
            :maxdepth: 1

            customized_render.rst

        .. raw:: html

            <img style="max-width: 240px;" src="/_images/customized_render-2.png"/>


.. grid::

    .. grid-item-card::

        .. toctree::
            :maxdepth: 1

            concatenation.rst

        .. raw:: html

            <img style="max-width: 480px;" src="/_images/concatenation-7.png"/>
